"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EntryAssetsResolver = void 0;
const createResolvedAsset = file => {
  const result = {
    ...file,
    aliases: file.aliases || []
  };
  /**
   * We need to remove unnecessary fields from the resolved assets.
   *
   * We cannot return specific fields, rather than deleting unnecessary ones, because a user can extend the file model
   * so we would not know which fields to return.
   */
  delete result.savedBy;
  delete result.savedOn;
  delete result.modifiedBy;
  delete result.modifiedOn;
  delete result.accessControl;
  delete result.createdBy;
  delete result.createdOn;
  delete result.tenant;
  delete result.locale;
  delete result.webinyVersion;
  return result;
};
class EntryAssetsResolver {
  constructor(params) {
    this.fetchFiles = params.fetchFiles;
  }
  async resolve(input) {
    const keys = [];
    const aliases = [];
    for (const asset of input) {
      if (asset.key) {
        keys.push(asset.key);
      } else if (asset.alias) {
        aliases.push(asset.alias);
      }
    }
    const assets = [];
    const where = {};
    if (keys.length > 0 && aliases.length > 0) {
      where.OR = [{
        key_in: keys
      }, {
        aliases_in: aliases
      }];
    } else if (keys.length > 0) {
      where.key_in = keys;
    } else if (aliases.length > 0) {
      where.aliases_in = aliases;
    } else {
      return assets;
    }
    const fetch = async after => {
      return this.fetchFiles({
        where,
        limit: 10000000,
        sort: ["id_ASC"],
        after
      });
    };
    let after = undefined;
    while (true) {
      /**
       * Unfortunately we must cast the result, because TS is not able to infer the correct type.
       */
      const {
        items,
        meta
      } = await fetch(after);
      for (const file of items) {
        assets.push(createResolvedAsset(file));
      }
      if (!meta.hasMoreItems) {
        return assets;
      }
      after = meta.cursor || undefined;
    }
  }
}
exports.EntryAssetsResolver = EntryAssetsResolver;

//# sourceMappingURL=EntryAssetsResolver.js.map